@@ -1,4 +1,4 @@
-from ha import *
+from homealone import *
 
 # TC74 temp sensor
 
